from carrots import Microclient
from carrots.common.functions import apply

class Microworker(Microclient):
    def __init__(self, uri, exchange, qin, qout, process):
        super().__init__(uri, exchange, qin=qin, qout=qout, process=process)

    def eat_carrot(self, *args):
        carrot = apply(self.process, *args)
        self.push_carrot(self.qout, carrot)

    def work(self):
        self.start()
        self.start_loop()


from setuptools import setup

setup(name='carrots',
      version='0.1.7',
      description='Library to build RabbitMQ architectures like you were playing with lego blocks',
      url='http://github.com/croccam/carrots',
      author='Croccam',
      author_email='antcarri@gmail.com',
      license='MIT',
      packages=['carrots'],
      zip_safe=False)